Installation of Yagot project
=======================================================

To install the latest released version of the
Yagot project into your active Python environment:

      $ pip install yagot

This will also install any prerequisite Python packages.

For more details and alternative ways to install, see
[Installation](https://yagot.readthedocs.io/en/latest/intro.html#installation).
